@@ -6,48 +6,48 @@ import re
 import utils.objectUtils as objUtils
 
 
-def to_snake_case(string):
+def to_snake_case(subject):
     '''
-        Convert a string to snake case.
+        Convert a subject to snake case.
 
         ----------
         Arguments
         -----------------
-        `string` {str}
-            The string to convert
+        `subject` {str}
+            The subject to convert
 
         Return
         ----------
         `return` {str}
-            The string converted to snake case
+            The subject converted to snake case
 
         Example
         ----------            
         BeepBoop Bleep blorp => beep_boop_bleep_blorp
     '''
-    string = str(string)
-    string = re.sub(r'([a-z])([A-Z])', r'\1_\2', string)
-    string = string.replace(' ', '_')
-    return string.lower()
+    subject = str(subject)
+    subject = re.sub(r'([a-z])([A-Z])', r'\1_\2', subject)
+    subject = subject.replace(' ', '_')
+    return subject.lower()
 
 
-def to_screaming_snake(string):
+def to_screaming_snake(subject):
     '''
-        Convert a string to screaming snake case.
+        Convert a subject to screaming snake case.
 
         ----------
         Arguments
         -----------------
-        `string` {str}
-            The string to convert
+        `subject` {str}
+            The subject to convert
 
         Return
         ----------
         `return` {str}
-            The string converted to screaming snake case
+            The subject converted to screaming snake case
 
         Example
         ----------            
         BeepBoop Bleep blorp => BEEP_BOOP_BLEEP_BLORP
     '''
-    return to_snake_case(string).upper()
+    return to_snake_case(subject).upper()
