@@ -1,7 +1,7 @@
 # import json
 # import hashlib
-import string
-import utils.objectUtils as objUtils
+# import string
+# import utils.objectUtils as objUtils
 
 
 def leftPad(subject, max_len=2, pad_char='0'):
@@ -31,6 +31,3 @@ def leftPad(subject, max_len=2, pad_char='0'):
     if slen <= max_len:
         subject = f"{pad_char * (max_len - slen)}{subject}"
     return subject
-
-
-print(leftPad("1", 4, "0"))
